@@ -501,6 +501,7 @@ void SPVM_COMPILER_use_default_loaded_classes(SPVM_COMPILER* compiler) {
   SPVM_COMPILER_use(compiler, "Stringable", "Stringable", 0);
   SPVM_COMPILER_use(compiler, "Countable", "Countable", 0);
   SPVM_COMPILER_use(compiler, "CallerInfo", "CallerInfo", 0);
+  SPVM_COMPILER_use(compiler, "Cloneable", "Cloneable", 0);
 }
 
 void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
@@ -512,20 +513,34 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
     const char* content = 
       "class Byte {\n"
       "  interface Stringable;\n"
+      "  interface Cloneable;\n"
       "  version_from SPVM;\n"
-      "  has value : ro byte;\n"
+      "  has value : rw byte\n"
+      "  set {\n"
+      "    if ($self->{is_read_only}) {\n"
+      "      die \"The object is read-only and its value cannot be changed.\";\n"
+      "    }\n"
+      "    $self->{value} = (byte)$_;\n"
+      "  };\n"
+      "  has is_read_only : ro byte;\n"
       "  static method new : Byte ($value : int) {\n"
       "    my $self = new Byte;\n"
       "    $self->{value} = (byte)$value;\n"
       "    return $self;\n"
       "  }\n"
+      "  method make_read_only : void () {\n"
+      "    $self->{is_read_only} = 1;\n"
+      "  }\n"
+      "  method clone : Byte () {\n"
+      "    return Byte->new($self->{value});\n"
+      "  }\n"
       "  method to_string : string () {\n"
       "    return (string)$self->{value};\n"
       "  }\n"
       "}";
     SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
   }
-  
+
   // Add Short class file
   {
     const char* class_name = "Short";
@@ -533,20 +548,34 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
     const char* content = 
       "class Short {\n"
       "  interface Stringable;\n"
+      "  interface Cloneable;\n"
       "  version_from SPVM;\n"
-      "  has value : ro short;\n"
+      "  has value : rw short\n"
+      "  set {\n"
+      "    if ($self->{is_read_only}) {\n"
+      "      die \"The object is read-only and its value cannot be changed.\";\n"
+      "    }\n"
+      "    $self->{value} = (short)$_;\n"
+      "  };\n"
+      "  has is_read_only : ro byte;\n"
       "  static method new : Short ($value : int) {\n"
       "    my $self = new Short;\n"
       "    $self->{value} = (short)$value;\n"
       "    return $self;\n"
       "  }\n"
+      "  method make_read_only : void () {\n"
+      "    $self->{is_read_only} = 1;\n"
+      "  }\n"
+      "  method clone : Short () {\n"
+      "    return Short->new($self->{value});\n"
+      "  }\n"
       "  method to_string : string () {\n"
       "    return (string)$self->{value};\n"
       "  }\n"
       "}";
     SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
   }
-  
+
   // Add Int class file
   {
     const char* class_name = "Int";
@@ -554,20 +583,34 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
     const char* content = 
       "class Int {\n"
       "  interface Stringable;\n"
+      "  interface Cloneable;\n"
       "  version_from SPVM;\n"
-      "  has value : ro int;\n"
+      "  has value : rw int\n"
+      "  set {\n"
+      "    if ($self->{is_read_only}) {\n"
+      "      die \"The object is read-only and its value cannot be changed.\";\n"
+      "    }\n"
+      "    $self->{value} = $_;\n"
+      "  };\n"
+      "  has is_read_only : ro byte;\n"
       "  static method new : Int ($value : int) {\n"
       "    my $self = new Int;\n"
       "    $self->{value} = $value;\n"
       "    return $self;\n"
       "  }\n"
+      "  method make_read_only : void () {\n"
+      "    $self->{is_read_only} = 1;\n"
+      "  }\n"
+      "  method clone : Int () {\n"
+      "    return Int->new($self->{value});\n"
+      "  }\n"
       "  method to_string : string () {\n"
       "    return (string)$self->{value};\n"
       "  }\n"
       "}";
     SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
   }
-  
+
   // Add Long class file
   {
     const char* class_name = "Long";
@@ -575,20 +618,34 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
     const char* content = 
       "class Long {\n"
       "  interface Stringable;\n"
+      "  interface Cloneable;\n"
       "  version_from SPVM;\n"
-      "  has value : ro long;\n"
+      "  has value : rw long\n"
+      "  set {\n"
+      "    if ($self->{is_read_only}) {\n"
+      "      die \"The object is read-only and its value cannot be changed.\";\n"
+      "    }\n"
+      "    $self->{value} = $_;\n"
+      "  };\n"
+      "  has is_read_only : ro byte;\n"
       "  static method new : Long ($value : long) {\n"
       "    my $self = new Long;\n"
       "    $self->{value} = $value;\n"
       "    return $self;\n"
       "  }\n"
+      "  method make_read_only : void () {\n"
+      "    $self->{is_read_only} = 1;\n"
+      "  }\n"
+      "  method clone : Long () {\n"
+      "    return Long->new($self->{value});\n"
+      "  }\n"
       "  method to_string : string () {\n"
       "    return (string)$self->{value};\n"
       "  }\n"
       "}";
     SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
   }
-  
+
   // Add Float class file
   {
     const char* class_name = "Float";
@@ -596,20 +653,34 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
     const char* content = 
       "class Float {\n"
       "  interface Stringable;\n"
+      "  interface Cloneable;\n"
       "  version_from SPVM;\n"
-      "  has value : ro float;\n"
+      "  has value : rw float\n"
+      "  set {\n"
+      "    if ($self->{is_read_only}) {\n"
+      "      die \"The object is read-only and its value cannot be changed.\";\n"
+      "    }\n"
+      "    $self->{value} = $_;\n"
+      "  };\n"
+      "  has is_read_only : ro byte;\n"
       "  static method new : Float ($value : float) {\n"
       "    my $self = new Float;\n"
       "    $self->{value} = $value;\n"
       "    return $self;\n"
       "  }\n"
+      "  method make_read_only : void () {\n"
+      "    $self->{is_read_only} = 1;\n"
+      "  }\n"
+      "  method clone : Float () {\n"
+      "    return Float->new($self->{value});\n"
+      "  }\n"
       "  method to_string : string () {\n"
       "    return (string)$self->{value};\n"
       "  }\n"
       "}";
     SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
   }
-  
+
   // Add Double class file
   {
     const char* class_name = "Double";
@@ -617,13 +688,27 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
     const char* content = 
       "class Double {\n"
       "  interface Stringable;\n"
+      "  interface Cloneable;\n"
       "  version_from SPVM;\n"
-      "  has value : ro double;\n"
+      "  has value : rw double\n"
+      "  set {\n"
+      "    if ($self->{is_read_only}) {\n"
+      "      die \"The object is read-only and its value cannot be changed.\";\n"
+      "    }\n"
+      "    $self->{value} = $_;\n"
+      "  };\n"
+      "  has is_read_only : ro byte;\n"
       "  static method new : Double ($value : double) {\n"
       "    my $self = new Double;\n"
       "    $self->{value} = $value;\n"
       "    return $self;\n"
       "  }\n"
+      "  method make_read_only : void () {\n"
+      "    $self->{is_read_only} = 1;\n"
+      "  }\n"
+      "  method clone : Double () {\n"
+      "    return Double->new($self->{value});\n"
+      "  }\n"
       "  method to_string : string () {\n"
       "    return (string)$self->{value};\n"
       "  }\n"
@@ -790,6 +875,19 @@ void SPVM_COMPILER_set_default_loaded_class_files(SPVM_COMPILER* compiler) {
       "}";
     SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
   }
+  
+  // Add Cloneable class file
+  {
+    const char* class_name = "Cloneable";
+    const char* rel_file = "Cloneable.spvm";
+    const char* content = 
+      "class Cloneable : interface_t {\n"
+      "  version_from SPVM;\n"
+      "  required method clone : object ();\n"
+      "}";
+    SPVM_COMPILER_set_class_file_with_members(compiler, class_name, rel_file, content);
+  }
+  
 }
 
 void SPVM_COMPILER_set_class_file_with_members(SPVM_COMPILER* compiler, const char* class_name, const char* rel_file, const char* content) {
