@@ -14,11 +14,10 @@ Short class in L<SPVM> represents a short value as an object.
   
   my $short_object = Short->new(5);
   my $short_value = $short_object->value;
+  $short_object->set_value(10);
 
 =head1 Details
 
-This class is immutable.
-
 This class is automatically loaded.
 
 =head1 Interfaces
@@ -26,6 +25,7 @@ This class is automatically loaded.
 =over 2
 
 =item * L<Stringable|SPVM::Stringable>
+=item * L<Cloneable|SPVM::Cloneable>
 
 =back
 
@@ -33,9 +33,15 @@ This class is automatically loaded.
 
 =head2 value
 
-C<has value : ro short;>
+C<has value : rw short;>
 
-The value.
+The value. If the L</"is_read_only"> field is 1, a compilation error or a runtime error occurs when setting the value.
+
+=head2 is_read_only
+
+C<has is_read_only : ro byte;>
+
+If this value is 1, the L</"value"> field is read-only.
 
 =head1 Class Methods
 
@@ -47,6 +53,18 @@ Creates a new L<Short|SPVM::Short> object with a C<short> $value.
 
 =head1 Instance Methods
 
+=head2 make_read_only
+
+C<method make_read_only : void ();>
+
+Sets L</"is_read_only"> field to 1.
+
+=head2 clone
+
+C<method clone : L<Short|SPVM::Short> ();>
+
+Creates a new L<Short|SPVM::Short> object that clones this object. The value of L</"is_read_only"> field in the new object is 0.
+
 =head2 to_string
 
 C<method to_string : string ();>
